<?php
$translations = array(
	'General_Locale' => 'he_IL.UTF-8',
	'General_TranslatorName' => '<a href="http://www.nirlah.com">Nirlah</a> - Nir Lahad',
	'General_TranslatorEmail' => 'nirlah@gmail.com',
	'General_EnglishLanguageName' => 'Hebrew',
	'General_OriginalLanguageName' => 'עברית',
	'General_LayoutDirection' => 'rtl',
	'General_HelloUser' => 'שלום, %s!',
	'General_OpenSourceWebAnalytics' => 'ניתוח פעילות אתרים בקוד פתוח',
	'General_Dashboard' => 'פאנל סקירה',
	'General_DashboardForASpecificWebsite' => 'פאנל סקירה לאתר מסויים',
	'General_MultiSitesSummary' => 'כל האתרים',
	'General_AllWebsitesDashboard' => 'פאנל סקירה לכל האתרים',
	'General_API' => 'API',
	'General_Widgets' => 'ווידג\'טים',
	'General_Settings' => 'הגדרות',
	'General_GiveUsYourFeedback' => 'העברת משוב למפתחים!',
	'General_Unknown' => 'לא ידוע',
	'General_Never' => 'לעולם לא',
	'General_Required' => 'דרוש %s',
	'General_NotValid' => '%s לא תקף',
	'General_Id' => 'מספר סידורי',
	'General_Error' => 'שגיאה',
	'General_Warning' => 'אזהרה',
	'General_BackToHomepage' => 'בחזרה לעמוד הראשי של Piwik',
	'General_Yes' => 'כן',
	'General_No' => 'לא',
	'General_Delete' => 'למחוק',
	'General_Report' => 'לדווח',
	'General_Edit' => 'לערוך',
	'General_Download' => 'להוריד',
	'General_Upload' => 'העלאה',
	'General_Ok' => 'או.קי.',
	'General_Close' => 'לסגור',
	'General_OrCancel' => 'או %s ביטול %s',
	'General_Logout' => 'להתנתק',
	'General_Username' => 'שם משתמש',
	'General_Description' => 'תיאור',
	'General_Done' => 'סיום',
	'General_Name' => 'שם',
	'General_Value' => 'ערך',
	'General_Details' => 'פרטים',
	'General_Default' => 'בררת מחדל',
	'General_Visit' => 'ביקור',
	'General_VisitorIP' => 'IP מבקר',
	'General_VisitorID' => 'מספר מבקר',
	'General_VisitType' => 'סוג מבקר',
	'General_DaysSinceLastVisit' => 'ימים מאז ביקור אחרון',
	'General_DaysSinceFirstVisit' => 'ימים מאז ביקור ראשון',
	'General_NumberOfVisits' => 'מספר ביוקרים',
	'General_NewVisitor' => 'מבקר חדש',
	'General_ReturningVisitor' => 'מבקר חוזר',
	'General_Date' => 'תאריך',
	'General_Period' => 'תקופה',
	'General_ChooseDate' => 'בחירת תאריך',
	'General_Today' => 'היום',
	'General_Yesterday' => 'אתמול',
	'General_CurrentWeek' => 'שבוע נוכחי',
	'General_CurrentMonth' => 'חודש נוכחי',
	'General_CurrentYear' => 'שנה נוכחית',
	'General_DateRange' => 'טווח תאריכים:',
	'General_DateRangeInPeriodList' => 'טווח תאריכים',
	'General_ApplyDateRange' => 'יישום טווח תאריכים',
	'General_InvalidDateRange_js' => 'טווח התאריכים לא תקף, נא לנסות שוב',
	'General_DateRangeFrom_js' => 'מ',
	'General_DateRangeTo_js' => 'עד',
	'General_PreviousDays' => '%s ימים קודמים (לא כולל היום)',
	'General_LastDays' => '%s ימים אחרונים (כולל היום)',
	'General_LoadingData' => 'טוען מידע...',
	'General_Loading_js' => 'טוען...',
	'General_GoTo' => 'עבור ל%s',
	'General_Next' => 'הבא',
	'General_Previous' => 'הקודם',
	'General_Search' => 'חיפוש',
	'General_Others' => 'אחרים',
	'General_Table' => 'טבלה',
	'General_Piechart' => 'גרף עוגה',
	'General_TagCloud' => 'ענן תגים',
	'General_VBarGraph' => 'גרף עמודות',
	'General_OpenInNewWindow_js' => 'פתיחה בחלון חדש',
	'General_SaveImageOnYourComputer_js' => 'בכדי לשמור את התמונה על מחשבך: כפתור ימני על התמונה ולחיצה על "שמירת תמונה בשם..."',
	'General_Refresh' => 'לרענן את העמוד',
	'General_Visitors' => 'מבקרים',
	'General_ExportThisReport' => 'לייצא מידע בפורמטים אחרים',
	'General_ExportAsImage_js' => 'לייצא כתמונה',
	'General_Export' => 'ייצוא',
	'General_YourChangesHaveBeenSaved' => 'השינויים נשמרו.',
	'General_ErrorRequest' => 'אופס… נוצרה בעיה בזמן הבקשה, נא לנסות שוב.',
	'General_ColumnNbUniqVisitors' => 'מבקרים יחודיים',
	'General_ColumnNbVisits' => 'ביקורים',
	'General_ColumnPercentageVisits' => '% ביקורים',
	'General_ColumnNbActions' => 'פעולות',
	'General_NbActions' => 'מספר פעולות',
	'General_ColumnMaxActions' => 'מקסימום פעולות בביקור בודד',
	'General_ColumnSumVisitLength' => 'הזמן הכולל שהשקיעו המבקרים (שניות)',
	'General_ColumnLabel' => 'כותרת',
	'General_ColumnConversionRate' => 'שעור המרה',
	'General_ColumnActionsPerVisit' => 'פעולות בכל ביקור',
	'General_VisitDuration' => 'משך ביקור ממוצע (בשניות)',
	'General_ColumnAvgTimeOnSite' => 'משך שהייה ממוצע באתר',
	'General_ColumnVisitDuration' => 'משך ביקור (בשניות)',
	'General_ColumnBounceRate' => 'שיעור קפיצה',
	'General_ColumnExitRate' => 'שיעור יציאה',
	'General_ColumnPageviews' => 'צפיות',
	'General_ColumnUniquePageviews' => 'צפיות יחודייות',
	'General_ColumnBounces' => 'קפיצות',
	'General_ColumnEntrances' => 'כניסות',
	'General_ColumnExits' => 'יציאות',
	'General_ColumnAverageTimeOnPage' => 'זמן ממוצע בעמוד',
	'General_ColumnValuePerVisit' => 'תפוקה בכל ביקור',
	'General_ColumnVisitsWithConversions' => 'ביקורים עם המרות',
	'General_YearsDays' => '%1$s שנים ו-%2$s ימים',
	'General_DaysHours' => '%1$s ימים ו-%2$s שעות',
	'General_HoursMinutes' => '%1$s שעות ו-%2$s דקות',
	'General_MinutesSeconds' => '%1$s דקות ו-%2$s שניות',
	'General_Seconds' => '%s שניות',
	'General_Save' => 'לשמור',
	'General_ForExampleShort' => 'לדוגמה',
	'General_YouMustBeLoggedIn' => 'חובה להתחבר למערכת בכדי לבצע פעולה זו.',
	'General_Website' => 'אתר',
	'General_GeneralSettings' => 'הגדרות כלליות',
	'General_AllowPiwikArchivingToTriggerBrowser' => 'ארכיון Piwik ירוץ כאשר צופים דרך הדפדפן בדוחות',
	'General_ArchivingInlineHelp' => 'עבור אתרים בעלי תעבורה בינוניתעד גבוהה, מומלץ לבטל את ארכיון Piwik בעת צפייה דרך הדפדפן בדוחות. במקום זאת, מומלץ להגדיר עבודה כרונית (cron job) שתעבד דוחות Piwik בכל שעה.',
	'General_ArchivingTriggerDescription' => 'מומלץ להתקנות גדולות יותר של Piwik, צריך %sלהגדיר עבודה כרונית%s שתעבד את הדוחות אוטומטית.',
	'General_SeeTheOfficialDocumentationForMoreInformation' => 'ראו %sתיעוד רשמי%s למידע נוסף.',
	'General_NSeconds' => '%s שניות',
	'General_SmallTrafficYouCanLeaveDefault' => 'לאתרים בעלי תעבורה נמוכה, ניתן להשאיר את ברירת המחדל של %s שניות ולגשת לדוחות בזמן אמת.',
	'General_MediumToHighTrafficItIsRecommendedTo' => 'לאתרים בעלי תעבודה בינונית עד גבוהה, אנו ממליצים לעבד דוחות להיום לכל היותר בכל חצי שעה (%s שניות) או בכל שעה (%s שניות)',
	'General_RequiresFlash' => 'הצגת גרפים ב-Piwik מצריכה Flash',
	'General_GraphHelp' => 'מידע נוסף עבור הצגת גרפים ב Piwik.',
	'General_NoDataForGraph' => 'חסר מידע עבור גרף זה.',
	'General_NoDataForTagCloud' => 'חסר מידע עבור ענן תגים זה.',
	'General_DisplaySimpleTable' => 'להציג טבלה פשוטה',
	'General_DisplayTableWithMoreMetrics' => 'להציג טבלה עם יותר נתונים',
	'General_DisplayTableWithGoalMetrics' => 'להציג טבלה עם נתוני יעדים',
	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s הוא פרוייקט שיתופי. %3$s כל מעריץ של Piwik יכול לתרום! כנסו ל %4$s כיצד לתרום לPiwik? %5$s',
	'General_YouAreViewingDemoShortMessage' => 'הנך צופה בגרסת ההדגמה של Piwik',
	'General_DownloadFullVersion' => '%1$sהורדת%2$s הגרסה המלאה! כנסו ל%3$s',
	'General_NewUpdatePiwikX' => 'עדכון חדש: Piwik %s',
	'General_AboutPiwikX' => 'אודות Piwik %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s עכשיו זמינה. %2$s נא לשדרג עכשיו! %3$s (ראו %4$s שינויים %5$s)',
	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s עכשיו זמינה. אנא הודיעו לבעלי האתר.',
	'General_NewReportsWillBeProcessedByCron' => 'כאשר ארכיון Piwik אינו מורץ על ידי הדפדפן, דוחות חדשים יעובדו ע"י עבודה כרונית (crontab).',
	'General_ReportsWillBeProcessedAtMostEveryHour' => 'דוחות יעובדו כמו כן לכל היותר בכל שעה.',
	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => 'בהנחה כי גניזת המידע לארכיון פועלת בצורה מהירה בתהקנה שלך, ניתן  להגדיר את העבודה הכרונית (crontab) לרוץ לעיתים תכופות יותר.',
	'General_BackToPiwik' => 'חזרה ל Piwik',
	'General_ShortMonth_1' => 'ינו\'',
	'General_ShortMonth_2' => 'פבר\'',
	'General_ShortMonth_3' => 'מרס',
	'General_ShortMonth_4' => 'אפר\'',
	'General_ShortMonth_5' => 'מאי',
	'General_ShortMonth_6' => 'יוני',
	'General_ShortMonth_7' => 'יולי',
	'General_ShortMonth_8' => 'אוג\'',
	'General_ShortMonth_9' => 'ספט\'',
	'General_ShortMonth_10' => 'אוק\'',
	'General_ShortMonth_11' => 'נוב\'',
	'General_ShortMonth_12' => 'דצמ\'',
	'General_LongMonth_1' => 'ינואר',
	'General_LongMonth_2' => 'פברואר',
	'General_LongMonth_3' => 'מרס',
	'General_LongMonth_4' => 'אפריל',
	'General_LongMonth_5' => 'מאי',
	'General_LongMonth_6' => 'יוני',
	'General_LongMonth_7' => 'יולי',
	'General_LongMonth_8' => 'אוגוסט',
	'General_LongMonth_9' => 'ספטמבר',
	'General_LongMonth_10' => 'אוקטובר',
	'General_LongMonth_11' => 'נובמבר',
	'General_LongMonth_12' => 'דצמבר',
	'General_ShortDay_1' => 'ב\'',
	'General_ShortDay_2' => 'ג\'',
	'General_ShortDay_3' => 'ד\'',
	'General_ShortDay_4' => 'ה\'',
	'General_ShortDay_5' => 'ו\'',
	'General_ShortDay_6' => 'ש\'',
	'General_ShortDay_7' => 'א\'',
	'General_LongDay_1' => 'שני',
	'General_LongDay_2' => 'שלישי',
	'General_LongDay_3' => 'רביעי',
	'General_LongDay_4' => 'חמישי',
	'General_LongDay_5' => 'שיש',
	'General_LongDay_6' => 'שבת',
	'General_LongDay_7' => 'ראשון',
	'General_Daily' => 'יומי',
	'General_Weekly' => 'שבועי',
	'General_Monthly' => 'חודשי',
	'General_ExceptionDatabaseVersion' => 'גרסאת ה%1$s שלך היא %2$s אך Piwik דורשת לפחות %3$s.',
	'General_ExceptionIncompatibleClientServerVersions' => 'גרסת צד הלקוח של %1$s היא %2$s בעוד גרסת צד השרת היא %3$s.',
	'General_ExceptionMissingFile' => 'קובץ חסר: %s',
	'General_ExceptionFilesizeMismatch' => 'אין התאמה במשקל הקובץ: %1$s (מצופה: %2$s, נמצא: %3$s)',
	'General_ExceptionFileIntegrity' => 'בדיקת שלמות נכשלה: %s',
	'General_ExceptionNonceMismatch' => 'לא ניתן לאמת את כרטיס האבטחה בטופס זה.',
	'General_PleaseSpecifyValue' => 'יד להגדיר ערך עבור \'%s\'.',
	'General_ExceptionMethodNotFound' => 'המתודה \'%s\' לא קיימת או לא נמצאה במודל \'%s\'.',
	'General_ExceptionInvalidRendererFormat' => 'הפורמט \'%s\' אינו תקין. יש לנסות אחד מהבאים במקום: %s.',
	'General_ExceptionInvalidPeriod' => 'התקופה \'%s\' לא נתמכת. יש לנסות את אחת מהבאות במקום: %s',
	'General_ExceptionInvalidDateRange' => 'התאריך \'%s\' אינו טווח תאריכים נכון. הוא צריך להיכתב בתבנית הבאה: %s.',
	'General_ExceptionGoalNotFound' => 'יעד %s לא נמצא.',
	'General_ExceptionUndeletableFile' => 'לא ניתן למחוק את %s',
	'General_ExceptionPrivilege' => 'לא ניתן לגשת למשאב זה מכיוון שהוא דורש גישת %s.',
	'General_ExceptionPrivilegeAtLeastOneWebsite' => 'לא ניתן לגשת למשאב זה מכיוון שהוא דורש גישת %s עבור אתר אחד לפחות.',
	'General_ExceptionPrivilegeAccessWebsite' => 'לא ניתן לגשת למשאב זה מכיוון שהוא דורש גישת %s עבור האתר שמספרו הסידורי הוא %d.',
	'General_ExceptionInvalidArchiveTimeToLive' => 'זמן החיים של ארכיון היום חייב להיות מספר שניות הגדול מ-0.',
	'General_ExceptionConfigurationFileNotFound' => 'קובץ ההגדרות {%s} לא נמצא.',
	'General_ExceptionUnreadableFileDisabledMethod' => 'קובץ ההגדרות {%s} לא ניתן לקריאה. המארח אולי חסם את %s.',
	'General_ExceptionInvalidToken' => 'הכרטיס לא תקף.',
	'General_ExceptionInvalidDateFormat' => 'תבנית התאריך מוכרחה להיות: %s או כל מילת מפתח שנתמכת על ידי פונקצית ה %s (ראו %s בשביל מידע נוסף)',
	'General_ExceptionLanguageFileNotFound' => 'קובץ השפה \'%s\' לא נמצא.',
	'General_WarningFileIntegritySkipped' => 'זוהתה סביבת פיתוח. נפסחה בדיקת תקינות קבצים.',
	'General_WarningFileIntegrityNoManifest' => 'לא ניתן לבצע בדיקת תקינות קבצים מכיוון שהקובץ manifest.inc.php חסר.',
	'General_WarningFileIntegrityNoMd5file' => 'לא ניתן לבצע בדיקת תקינות קבצים מכיוון שהפונקציה md5_file() חסרה.',
	'General_FileIntegrityWarningExplanation' => 'בדיקת תקינות קבצים נכשלה ודיווחה על מספר שגיאות. ייתכן וזה נגרם עקב העלאה חלקית או כושלת של קבצי המערכת. יש להעלות את הקבצים מחדש במצב BINARY ולרענן את העמוד עד שלא יוצגו שגיאות.',
	'General_UseSMTPServerForEmail' => 'שימוש בשרת SMTP עבור דוא"ל',
	'General_SmtpServerAddress' => 'כתובת שרת SMTP',
	'General_SmtpPort' => 'נתיב SMTP',
	'General_AuthenticationMethodSmtp' => 'שיטת אימות עבור SMTP',
	'General_SmtpUsername' => 'שם משתמש SMTP',
	'General_SmtpPassword' => 'סיסמת SMTP',
	'General_SmtpEncryption' => 'הצפנת SMTP',
	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'יש לבחור "כן" אם רוצים או חייבים לשלוח דוא"ל דרך שרת ולא דרך פונקצית הדוא"ל המקומית',
	'General_OptionalSmtpPort' => 'אופציונלי. ברירת המחדל היא 25 עבור לא מוצפן ו-TLS SMTP, 465 עבור SSL SMTP.',
	'General_OnlyUsedIfUserPwdIsSet' => 'משומש רק אם שם המשתמש/סיסמה מוגדרים, יש לברר עם הספק במקרה של חוסר וודאות באיזה שיטה לבחור.',
	'General_OnlyEnterIfRequired' => 'יש להזין שם משתמש רק אם שרת ה-SMTP מבקש זאת.',
	'General_OnlyEnterIfRequiredPassword' => 'יש להזין סיסמה רק אם שרת ה-SMTP מבקש זאת.',
	'General_WarningPasswordStored' => '%sאזהרה:%s הסיסמה תאוכסן בקובץ ההגדרות וחושפת לכל כיצד להתחבר.',
	'General_EncryptedSmtpTransport' => 'יש להזין את שכבת ההצפנה הדרושה ע"י שרת ה-SMTP שלך.',
	'General_InvalidResponse' => 'המידע שהתקבל אינו תקף.',
	'General_ChooseLanguage' => 'בחירת שפה',
	'General_ChoosePeriod' => 'בחירת תקופה',
	'General_ChooseWebsite' => 'בחירת אתר',
	'General_Language' => 'שפה',
	'General_PleaseUpdatePiwik' => 'יש לעדכן את ה-Piwik שלך',
	'General_RequestTimedOut' => 'בקשת מידע מ %s נקטעה. יש לנסות שוב.',
	'Actions_PluginDescription' => 'מדווח על מספר צפיות, קישורים יוצאים והורדות. מעקב אחרי קישורים יוצאים והורדות הינו אוטומטי.',
	'Actions_Actions' => 'פעולות',
	'Actions_SubmenuPages' => 'דפים',
	'Actions_SubmenuPagesEntry' => 'דפי כניסה',
	'Actions_SubmenuPagesExit' => 'דפי יציאה',
	'Actions_SubmenuPageTitles' => 'כותרות הדפים',
	'Actions_SubmenuOutlinks' => 'קישורים יוצאים',
	'Actions_SubmenuDownloads' => 'הורדות',
	'Actions_ColumnClicks' => 'קליקים',
	'Actions_ColumnUniqueClicks' => 'קליקים ייחודיים',
	'Actions_ColumnDownloads' => 'הורדות',
	'Actions_ColumnUniqueDownloads' => 'הורדת יחודיים',
	'Actions_ColumnPageName' => 'שם הדף',
	'Actions_ColumnPageURL' => 'כתובת הדף',
	'Actions_ColumnClickedURL' => 'כתובת שנלחצה',
	'Actions_ColumnDownloadURL' => 'הורדת כתובת',
	'Actions_ColumnEntryPageURL' => 'כתובת עמוד כניסה',
	'Actions_ColumnEntryPageTitle' => 'כותרת עמוד כניסה',
	'Actions_ColumnExitPageURL' => 'כתובת עמוד יציאה',
	'Actions_ColumnExitPageTitle' => 'כותרת עמוד יציאה',
	'AnonymizeIP_PluginDescription' => 'הסתרת הספרות האחרונות של כתובת הIP של המבקרים בכדי להתיישר עם החוקים / תקנות המקומיים.',
	'API_PluginDescription' => 'כל המידע בPiwik חופשי לשימוש דרך APIים פשוטים. תוסף זה הוא נקודת הגישה לשירותי רשת, אליהם ניתן לגשת בכדי לקבל ניתוח על אתרך במספר פורמטים: xml, json, php, csv וכו\'.',
	'API_QuickDocumentationTitle' => 'מדריך מקוצר לAPI',
	'API_GenerateVisits' => 'אם אין לך מידע להיום ניתן קודם כל לחולל מידע בעזרת התוסף %s. ניתן להפעיל את התוסף %s, ולאחר מכן לחולל מידע על מבקרים דרך פאנל הניהול של Piwik.',
	'API_MoreInformation' => 'למידע נוסף עבור הAPIים של Piwik, מומלץ להציץ ב%sהיכרות עם הAPI של Piwik%s וגם ב%sהעמקה אודות הAPI של Piwik%s.',
	'API_UserAuthentication' => 'אימות משתמש',
	'API_UsingTokenAuth' => 'אם ברצונך %s לדרוש מידע מתוך סקריטפ, עבודה כרונית וכד\' %s יש צורך להוסיף את הפרמטר %s לכל קריאת API מהURLים שדורשים אימות.',
	'API_KeepTokenSecret' => 'הtoken_auth סודי ביותר כמו שם המשתמש והסיסמה, %s אין לשתף אף אחד בפרטים אלו%s!',
	'API_LoadedAPIs' => '%s APIים נטענו בהצלחה',
	'CoreAdminHome_PluginDescription' => 'אזור הניהול של Piwik.',
	'CoreAdminHome_MenuGeneralSettings' => 'הגדרות כלליות',
	'CoreAdminHome_Administration' => 'ניהול',
	'CoreAdminHome_EmailServerSettings' => 'הגדרות שרת אימייל',
	'CoreAdminHome_OptOutForYourVisitors' => 'התחמקות מPiwik עבור גולשים',
	'CoreHome_PluginDescription' => 'מבנה דוחות הפעילות.',
	'CoreHome_WebAnalyticsReports' => 'דוחות פעילות',
	'CoreHome_JavascriptDisabled' => 'בכדי לצפות בPiwik חובה להפעיל JavaScript.<br/>בכל מקרה, נראה כי הJavaScript מנוטרל או לא נתמך על יד הדפדפן שלך.<br/>בכדי לצפות בצורה סטנדרטית, יש להפעיל את הJavaScript על ידי שינוי הגדרות הדפדפן, ולאחר מכן %1$sלנסות שוב%2$s.<br/>',
	'CoreHome_ThereIsNoDataForThisReport' => 'אין מידע להצגה עבור הדוח',
	'CoreHome_CategoryNoData' => 'אין מידע בקטגוריה זו. נא לנסות "לכלול את כלל האוכלוסייה"',
	'CoreHome_ShowJSCode' => 'הצגת הJavaScript להטמעה',
	'CoreHome_PageOf_js' => '%1$s מתוך %2$s',
	'CoreHome_PeriodDay' => 'יום',
	'CoreHome_PeriodWeek' => 'שבוע',
	'CoreHome_PeriodMonth' => 'חודש',
	'CoreHome_PeriodYear' => 'שנה',
	'CoreHome_PeriodDays' => 'ימים',
	'CoreHome_PeriodWeeks' => 'שבועות',
	'CoreHome_PeriodMonths' => 'חודשים',
	'CoreHome_PeriodYears' => 'שנים',
	'CoreHome_DaySu_js' => 'א\'',
	'CoreHome_DayMo_js' => 'ב\'',
	'CoreHome_DayTu_js' => 'ג\'',
	'CoreHome_DayWe_js' => 'ד\'',
	'CoreHome_DayTh_js' => 'ה\'',
	'CoreHome_DayFr_js' => 'ו\'',
	'CoreHome_DaySa_js' => 'ש\'',
	'CoreHome_ShortDay_1_js' => 'א\'',
	'CoreHome_ShortDay_2_js' => 'ב\'',
	'CoreHome_ShortDay_3_js' => 'ג\'',
	'CoreHome_ShortDay_4_js' => 'ד\'',
	'CoreHome_ShortDay_5_js' => 'ה\'',
	'CoreHome_ShortDay_6_js' => 'ו\'',
	'CoreHome_ShortDay_7_js' => 'ש\'',
	'CoreHome_LongDay_1_js' => 'ראשון',
	'CoreHome_LongDay_2_js' => 'שני',
	'CoreHome_LongDay_3_js' => 'שלישי',
	'CoreHome_LongDay_4_js' => 'רביעי',
	'CoreHome_LongDay_5_js' => 'חמישי',
	'CoreHome_LongDay_6_js' => 'שישי',
	'CoreHome_LongDay_7_js' => 'שבת',
	'CoreHome_ShortMonth_1_js' => 'ינו',
	'CoreHome_ShortMonth_2_js' => 'פבר',
	'CoreHome_ShortMonth_3_js' => 'מרץ',
	'CoreHome_ShortMonth_4_js' => 'אפר',
	'CoreHome_ShortMonth_5_js' => 'מאי',
	'CoreHome_ShortMonth_6_js' => 'יונ',
	'CoreHome_ShortMonth_7_js' => 'יול',
	'CoreHome_ShortMonth_8_js' => 'אוג',
	'CoreHome_ShortMonth_9_js' => 'ספט',
	'CoreHome_ShortMonth_10_js' => 'אוק',
	'CoreHome_ShortMonth_11_js' => 'נוב',
	'CoreHome_ShortMonth_12_js' => 'דצמ',
	'CoreHome_MonthJanuary_js' => 'ינואר',
	'CoreHome_MonthFebruary_js' => 'פברואר',
	'CoreHome_MonthMarch_js' => 'מרץ',
	'CoreHome_MonthApril_js' => 'אפריל',
	'CoreHome_MonthMay_js' => 'מאי',
	'CoreHome_MonthJune_js' => 'יוני',
	'CoreHome_MonthJuly_js' => 'יולי',
	'CoreHome_MonthAugust_js' => 'אוגוסט',
	'CoreHome_MonthSeptember_js' => 'ספטמבר',
	'CoreHome_MonthOctober_js' => 'אוקטובר',
	'CoreHome_MonthNovember_js' => 'נובמבר',
	'CoreHome_MonthDecember_js' => 'דצמבר',
	'CorePluginsAdmin_PluginDescription' => 'ממשק ניהול תוספים.',
	'CorePluginsAdmin_Plugins' => 'תוספים',
	'CorePluginsAdmin_PluginsManagement' => 'ניהול תוספים',
	'CorePluginsAdmin_MainDescription' => 'תוספים מרחיבים את היכולות של Piwik. ברגע שתוסף מותקן, ניתן להפעילו או לבטלו כאן.',
	'CorePluginsAdmin_Plugin' => 'תוסף',
	'CorePluginsAdmin_Version' => 'גירסה',
	'CorePluginsAdmin_Status' => 'מצב',
	'CorePluginsAdmin_Action' => 'פעולה',
	'CorePluginsAdmin_AuthorHomepage' => 'אתר היוצר',
	'CorePluginsAdmin_LicenseHomepage' => 'אתר רישון השימוש',
	'CorePluginsAdmin_PluginHomepage' => 'אתר התוסף',
	'CorePluginsAdmin_Activated' => 'הופעל',
	'CorePluginsAdmin_Active' => 'פעיל',
	'CorePluginsAdmin_Inactive' => 'לא פעיל',
	'CorePluginsAdmin_Deactivate' => 'כבה',
	'CorePluginsAdmin_Activate' => 'הפעל',
	'CorePluginsAdmin_MenuPlugins' => 'תוספים',
	'CoreUpdater_PluginDescription' => 'מנגנון השדרוג של Piwik',
	'CoreUpdater_UpdateTitle' => 'שדרוג',
	'CoreUpdater_DatabaseUpgradeRequired' => 'שדרוג בסיס נתונים נדרש',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'מסד הנתונים של הPiwik שלך לא בתוקף, חובה לשדרג אותו לפני שנמשיך.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'מסד הנתונים של Piwik ישודרג מגירסה %1$s לגירסה %2$s.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'התוספים הבאים ישודרגו: %s.',
	'CoreUpdater_NoteForLargePiwikInstances' => 'הערה חשובה עבור אתרי Piwik גדולים',
	'CoreUpdater_TheUpgradeProcessMayFailExecuteCommand' => 'במידה ויש לך מסד נתונים גדול של Piwik, השדרוג עלול לקחת זמן רב מדי עבור הדפדפן. במצב זה, ניתן להריץ את השדרוג דרך שורת הפקודה: %s',
	'CoreUpdater_YouCouldManuallyExecuteSqlQueries' => 'במידה ואין ביכלותך לשדרג דרך שורת הפקודה ובמידה וPiwik נכשלת בשדרוג (עקב השעיה של מסד הנתונים, השעיה של הדפדפן או כל בעיה אחרת), ניתן להריץ באופן ידני את השאילתות לשדרוג Piwik.',
	'CoreUpdater_ClickHereToViewSqlQueries' => 'צפייה והעתקת השאילתות שירוצו',
	'CoreUpdater_NoteItIsExpectedThatQueriesFail' => 'יש לשים לב: במידה והשאילתות מורצות באופן ידני, צפוי כי חלק מהם יכשלו. במצב זה, יש להתעלם מהשגיאות, ולהריץ את הבאות בתור.',
	'CoreUpdater_ReadyToGo' => 'שנתחיל?',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'תהליך שדרוג מסד הנתונים צפוי לארוך זמן-מה, יש להתאזר בסבלנות.',
	'CoreUpdater_UpgradePiwik' => 'שדרוג Piwik',
	'CoreUpdater_ErrorDIYHelp' => 'במידה והינך משתמש/ת מתקדמ/ת ונתקלת בשגיאה בשדרוג מסד הנתונים:',
	'CoreUpdater_ErrorDIYHelp_1' => 'זיהוי ותיקון מקור התקלה (לדוגמה memory_limit או max_execution_time)',
	'CoreUpdater_ErrorDIYHelp_2' => 'הרצת השאילתות שנותרו בשדרוג ונכשלו',
	'CoreUpdater_ErrorDIYHelp_3' => 'שדרוג ידני של טבלת \'option\' במסד הנתונים של Piwik, הגדרת הערך של version_core לגירסה של השדרוג הכושל',
	'CoreUpdater_ErrorDIYHelp_4' => 'יש להריץ מחדש את המשדרג (דרך הדפדפן או שורת הפקודה) בכדי להמשיך בשדרוגים שנותרו',
	'CoreUpdater_ErrorDIYHelp_5' => 'לדווח על התקלה (והפיתרון) כך שPiwik תוכל להשתפר',
	'CoreUpdater_HelpMessageContent' => 'יש לעיין ב%1$sשאלות ותשובות של Piwik %2$s בכדי לקבל הסבר עבור רוב השגיאות הנפוצות במהלך השדרוג. %3$s מומלץ להתייעץ עם מנהל המערכת שלך - הם בדרך כלל מסוגלים לעזור לך עם השגיאה שסביר להניח קשורה למסד הנתונים או לשרת.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'שגיאה קריטית במהלך תהליך השדרוג:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'ההודעה להעיל הינה שגיאת הליבה. היא אמורה להסביר את הגורם, במידה ודרושה עזרה נוספת, אנא:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'השדרוג הושלם בהצלחה, בכל אופן התרחשו מספר תקלות במהלך התהליך. יש לקרוא את התיאור להעיל לפרטים. לעזרה נוספת:',
	'CoreUpdater_UpgradeComplete' => 'השדרוג הושלם!',
	'CoreUpdater_WarningMessages' => 'הודעה אזהרה:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'שגיאה בהמלך שדרוגי תוסף:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'הפעלנו באופן אוטומטי את התוספים הבאים: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik שודרגה בהצלחה!',
	'CoreUpdater_ContinueToPiwik' => 'חזרה לPiwik',
	'CoreUpdater_UpdateAutomatically' => 'שדרוג אוטומטי',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'ישנה גירסה חדשה של Piwik זמינה עבורך',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'ניתן לשדרג לגירסה %s באופן אוטומטי או להוריד חבילה ולהתקינה באופן ידני:',
	'CoreUpdater_YouMustDownloadPackageOrFixPermissions' => 'Piwik לא מצליחה לשכתב את ההתקנה הנוכחית. ניתן לתקן את הרשאות התיקיה/קובץ או להוריד את החבילה ולהתקין את גירסה %s באופן ידני:',
	'CoreUpdater_DownloadX' => 'להוריד %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'ההתקנה-בקליק-אחד של Piwik בוטלה. במידה ואין ביכלותך לתקן את הודעת השגיאה להעיל, מומלץ לשדרג את Piwik באופן ידני. %1$s יש לעיין ב%2$sהוראות השדרוג%3$s בכדי להתחיל!',
	'CoreUpdater_DownloadingUpdateFromX' => 'מוריד עדכון מ%s',
	'CoreUpdater_UnpackingTheUpdate' => 'מחלץ את העדכון',
	'CoreUpdater_VerifyingUnpackedFiles' => 'מאמת את הקבצים המחולצים',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'יוצר גיבוי של קובץ ההגדרות ב%s',
	'CoreUpdater_InstallingTheLatestVersion' => 'מתקין את הגירסה העדכנית ביותר',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'שדרוג Piwik הושלם בהצלחה!',
	'CoreUpdater_EmptyDatabaseError' => 'מסד התונים %s ריק. צריך לערוך או להסיר את קובץ ההגדרות של Piwik.',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'גרסת הPiwik שלך %s עדכנית.',
	'CoreUpdater_ExceptionArchiveIncompatible' => 'ארכיון לא תואם: %s.',
	'CoreUpdater_ExceptionArchiveEmpty' => 'ארכיון ריק.',
	'CoreUpdater_ExceptionArchiveIncomplete' => 'ארכיון לא שלם: חלק מהקבצים חסרים (לדוגמה: %s).',
	'CustomVariables_PluginDescription' => 'משתנים מותאמים הם זוגות של שמות וערכים שניתן להגדיר לביקור בעזרת פונקצית setVisitCustomVariables() שבתוך ה-Javascript API. לאחר מכן, Piwik תדווח כמו ביקורים, עמודים, המרות היו לכל אחד מהמשתנים ואת ערכם.',
	'CustomVariables_CustomVariables' => 'משתנים מותאמים אישים',
	'CustomVariables_ColumnCustomVariableName' => 'שם המשתנה',
	'CustomVariables_ColumnCustomVariableValue' => 'ערך המשתנה',
	'Dashboard_PluginDescription' => 'סקירה כללית של ניתוח פעילות אתרך. ניתן להתאים אישית את פאנל הסקירה: הוספת יישומונים, שינוי סדר הופעתם. כל משתמש יכול לגש ללוח סקירה כללית משל עצמו.',
	'Dashboard_Dashboard' => 'פאנל סקירה',
	'Dashboard_DeleteWidgetConfirm' => 'למחוק את היישומון מפאנל הסקירה? 100%?',
	'Dashboard_SelectWidget' => 'בחירת היישומון להוספה לפאנל הסקירה',
	'Dashboard_AddPreviewedWidget_js' => 'הוספת היישומון המוצג לפאנל הסקירה',
	'Dashboard_WidgetPreview_js' => 'הצגת יישומון',
	'Dashboard_Close_js' => 'סגירה',
	'Dashboard_Maximise_js' => 'הגדלה',
	'Dashboard_TitleWidgetInDashboard_js' => 'היישומון כבר נמצא בפאנל הסקירה',
	'Dashboard_TitleClickToAdd_js' => 'הוספה לפאנל הסקירה',
	'Dashboard_LoadingWidget_js' => 'טוען יישומון, נא להמתין...',
	'Dashboard_WidgetNotFound_js' => 'יישומון לא נמצא',
	'DBStats_PluginDescription' => 'תוסף זה מדווח על צריכת מסד הנתונים על ידי הטבלאות של Piwik.',
	'DBStats_DatabaseUsage' => 'צריכת מסד נתונים',
	'DBStats_MainDescription' => 'Piwik מאכסנת את כל המידע אודות ניתוח פעילות הרשת במסד נתונים. כרגע, טבלאות Piwik צורכות %s.',
	'DBStats_LearnMore' => 'בכדי ללמוד עוד אודות כיצד Piwik מעבדת מידע וכיצד לשפר את ביצועיה של Piwik עבור אתרים בעלי תעבורה בינונית עד גבוהה, מומלץ להציץ במדריך %s.',
	'DBStats_Table' => 'טבלה',
	'DBStats_RowCount' => 'מספר שורות',
	'DBStats_DataSize' => 'משקל מידע',
	'DBStats_IndexSize' => 'משקל מפתח (index)',
	'DBStats_TotalSize' => 'משקל כולל',
	'ExampleAPI_PluginDescription' => 'תוסף לדוגמה: כיצד להכין API לתוסף שלך, שייצא מידע במספר פורמטים ללא תכנות מיוחד?',
	'ExampleFeedburner_PluginDescription' => 'תוסף לדוגמה: כיצד להציג את עוקבי הFeedburner שלך ביישומון בפאנל הסקירה?',
	'ExampleFeedburner_Help' => 'עזרה אודות סטטיסטיקת הFeed',
	'ExampleRssWidget_PluginDescription' => 'תוסף לדוגמה: כיצד ליצור יישומון חדש המציג עדכוני RSS?',
	'ExampleUI_PluginDescription' => 'תוסף לדוגמה: תוסף זה מדגים כיצד לעבוד עם הממשק של Piwik: יצירת טבלאות, גרפים וכדומה.',
	'Installation_Installation' => 'התקנה',
	'Installation_InstallationStatus' => 'מצב התקנה',
	'Installation_PercentDone' => '%s %% עברו',
	'Installation_DatabaseSetup' => 'התקנת מסד נתונים',
	'Installation_DatabaseSetupServer' => 'שרת',
	'Installation_DatabaseSetupLogin' => 'משתמש',
	'Installation_DatabaseSetupPassword' => 'סיסמה',
	'Installation_DatabaseSetupDatabaseName' => 'שם מסד הנתונים',
	'Installation_DatabaseSetupTablePrefix' => 'מקדם טבלאות',
	'Installation_DatabaseSetupAdapter' => 'מתאם',
	'Installation_Congratulations' => 'ברכות',
	'Installation_SetupWebsite' => 'הגדרת אתר',
	'Installation_SetupWebSiteName' => 'שם האתר',
	'Installation_SetupWebSiteURL' => 'כתובת האתר',
	'Installation_SuperUserLogin' => 'כניסת משתמש-על',
	'Installation_Password' => 'סיסמה',
	'Installation_PasswordRepeat' => 'סיסמה (שוב)',
	'Installation_Email' => 'דוא"ל',
	'Installation_PasswordDoNotMatch' => 'סיסמה לא תואמת',
	'Installation_Requirements' => 'דרישות Piwik',
	'Installation_Optional' => 'אופציונלי',
	'Installation_Extension' => 'הרחבה',
	'Installation_SystemCheck' => 'בדיקת מערכת',
	'Installation_SystemCheckPhp' => 'גרסת PHP',
	'Installation_SystemCheckGD' => 'GD > 2.x (גרפיקה)',
	'Installation_Welcome' => 'ברוכים הבאים!',
	'Login_LoginPasswordNotCorrect' => 'שם משתמש וסיסמה אינם תואמים',
	'Login_Password' => 'סיסמה',
	'Login_PasswordRepeat' => 'סיסמה (שוב)',
	'Login_ChangePassword' => 'שינוי סיסמה',
	'Login_LoginOrEmail' => 'שם משתמש או אימייל',
	'Login_RememberMe' => 'זכור אותי',
	'Login_LogIn' => 'התחברות',
	'Login_Logout' => 'התנתקות',
	'Login_LostYourPassword' => 'שכחת סיסמה?',
	'Login_RemindPassword' => 'שליחת איפוס סיסמה',
	'Login_PasswordResetToken' => 'כרטיס איפוס סיסמה',
	'Login_PasswordsDoNotMatch' => 'הסיסמאות אינן תואמות.',
	'Login_PasswordSuccessfullyChanged' => 'סיסמה שונתה בהצלחה!',
	'Login_InvalidUsernameEmail' => 'שם משתמש ו/או אימייל לא תקניים',
	'Login_MailTopicPasswordRecovery' => 'שחזור סיסמה',
	'TranslationsAdmin_PluginDescription' => 'עזרו לתרגם את Piwik לשפה שלכם.',
	'TranslationsAdmin_MenuTranslations' => 'תרגומים',
	'TranslationsAdmin_MenuLanguages' => 'שפות',
	'TranslationsAdmin_LanguageCode' => 'קוד שפה',
	'TranslationsAdmin_Plugin' => 'תוסף',
	'TranslationsAdmin_Definition' => 'הגדרה',
	'TranslationsAdmin_DefaultString' => 'ביטוי ברירת מחדל (אנגלית)',
	'TranslationsAdmin_TranslationString' => 'ביטוי מתורגם (שפה נוכחית: %s)',
	'TranslationsAdmin_Translations' => 'תרגומים',
	'TranslationsAdmin_FixPermissions' => 'נא לתקן הרשאות מערכת קבצים',
	'TranslationsAdmin_AddLanguage' => 'הוספת שפה',
	'TranslationsAdmin_Export' => 'ייצוא שפה',
	'TranslationsAdmin_Import' => 'ייבוא שפה',
	'TranslationsAdmin_ShowOnlyEmpty' => 'הצגת ביטויים חסרים בלבד',
	'VisitsSummary_PluginDescription' => 'מדווח על ניתוח המספרים הכללי: ביקורים, מבקרים יחודיים, מספר פעולות, שיעור קפיצה וכו\'',
	'VisitsSummary_VisitsSummary' => 'תקציר ביקורים',
	'VisitsSummary_NbVisits' => '%s ביקורים',
	'VisitsSummary_NbUniqueVisitors' => '%s מבקרים יחודיים',
	'VisitsSummary_NbActionsDescription' => '%s פעולות (צפייה בעמודים, הורדות וקישורים יוצאים)',
	'VisitsSummary_AverageVisitDuration' => '%s זמן ביקור ממוצע',
	'VisitsSummary_MaxNbActions' => '%s מספר פעולות מקסימלי בביקור אחד',
	'VisitsSummary_NbActionsPerVisit' => '%s פעולות בביקור',
	'VisitsSummary_NbVisitsBounced' => '%s ביקורים קפצו (עזבו את האתר אחרי עמוד אחד)',
	'VisitsSummary_EvolutionOverLastPeriods' => 'צמיחה ב%s האחרון/ה',
	'VisitsSummary_GenerateTime' => '%s שניות בכדי לחולל את העמוד',
	'VisitsSummary_GenerateQueries' => '%s שאילתות בוצעו',
	'VisitsSummary_WidgetLastVisits' => 'גרף ביקורים אחרונים',
	'VisitsSummary_WidgetVisits' => 'מבט כללי על ביקורים',
	'VisitsSummary_WidgetLastVisitors' => 'גרף מבקרים יחודיים אחרונים',
	'VisitsSummary_WidgetOverviewGraph' => 'מבט כללי עם גרף',
	'VisitsSummary_SubmenuOverview' => 'מבט כללי',
	'VisitTime_SubmenuTimes' => 'זמנים',
	'Widgetize_PluginDescription' => 'התוסף מקל מאוד על ייצוא יישומונים של Piwik מבלוג, אתר או בIgoogle וNetvibes!',
	'PDFReports_PDF' => 'PDF',
	'PDFReports_SendReportTo' => 'שלח דוח אל',
	'PDFReports_SentToMe' => 'שלח אלי',
);
